==> qmmp-plugin-pack-1.4.0.tar.bz2: qmmp-plugin-pack-1.4.0/src/Transports/ytb/translations/ytb_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>YtbInputFactory</name>
    <message>
        <location filename="../ytbinputfactory.cpp" line="36"/>
        <source>Youtube Plugin</source>
        <translation>Greffon Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="60"/>
        <source>not found</source>
        <translation>non trouvé</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="62"/>
        <source>About Youtube Transport Plugin</source>
        <translation>À propos du greffon de transport Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="63"/>
        <source>Qmmp Youtube Transport Plugin</source>
        <translation>Greffon de transport Youtube pour Qmmp</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="64"/>
        <source>This plugin adds feature to play audio from Youtube using &lt;a href=&quot;https://youtube-dl.org/&quot;&gt;youtube-dl&lt;/a&gt; utility</source>
        <translation>Ce greffon ajoute la possibilité de lire des morceaux audio provenant de Youtube en utilisant l&apos;utilitaire &lt;a href=&quot;https://youtube-dl.org/&quot;&gt;youtube-dl&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="66"/>
        <source>youtube-dl version: %1</source>
        <translation>version de youtube-dl: %1</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="67"/>
        <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation>Écrit par: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
    </message>
</context>
<context>
    <name>YtbInputSource</name>
    <message>
        <location filename="../ytbinputsource.cpp" line="148"/>
        <source>Uploader</source>
        <translation>Téléverseur</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="149"/>
        <source>Upload date</source>
        <translation>Date de téléversement</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="150"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Transports/ytb/translations/ytb_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>YtbInputFactory</name>
    <message>
        <location filename="../ytbinputfactory.cpp" line="36"/>
        <source>Youtube Plugin</source>
        <translation>Greffon Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="69"/>
        <source>About Youtube Transport Plugin</source>
        <translation>À propos du greffon de transport Youtube</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="70"/>
        <source>Qmmp Youtube Transport Plugin</source>
        <translation>Greffon de transport Youtube pour Qmmp</translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="71"/>
        <source>This plugin adds feature to play audio from Youtube using %1 utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="73"/>
        <source>%1 version: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytbinputfactory.cpp" line="74"/>
        <source>Written by: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</source>
        <translation>Écrit par: Ilya Kotov &amp;lt;forkotov02@ya.ru&amp;gt;</translation>
    </message>
</context>
<context>
    <name>YtbInputSource</name>
    <message>
        <location filename="../ytbinputsource.cpp" line="184"/>
        <source>Uploader</source>
        <translation>Téléverseur</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="185"/>
        <source>Upload date</source>
        <translation>Date de téléversement</translation>
    </message>
    <message>
        <location filename="../ytbinputsource.cpp" line="186"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
</context>
</TS>
